"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _useSyntaxHighlighter = require("../../hooks/useSyntaxHighlighter");
var _styleTransformer = require("../../utils/style-transformer");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const monospaceFont = _reactNative.Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const styles = _reactNative.StyleSheet.create({
  scrollView: {
    flex: 1,
    minHeight: 20
  },
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme
}) => {
  console.log('theme:', theme);
  const stylesheet = (0, _react.useMemo)(() => {
    const styles = (0, _styleTransformer.getRNStylesFromShikiStyle)(theme);
    console.log('Generated stylesheet:', styles);
    return styles;
  }, [theme]);
  const {
    tokens
  } = (0, _useSyntaxHighlighter.useSyntaxHighlighter)({
    text,
    language,
    languageId,
    theme
  });
  const renderToken = (token, index, lineIndex) => {
    // Ensure to collect all styles associated with the token's scopes
    const tokenScopes = Array.isArray(token.scope) ? token.scope : [token.scope];
    const tokenStylesArray = tokenScopes.map(scope => stylesheet[scope] || {});
    const combinedStyles = _reactNative.StyleSheet.flatten([...tokenStylesArray, {
      fontFamily: monospaceFont,
      ...(token.color && {
        color: token.color
      }),
      ...(token.fontStyle === 'italic' && stylesheet.italic),
      ...(token.fontWeight === 'bold' && stylesheet.bold)
    }]);
    console.log(`Rendering token: ${token.content}, styles:`, combinedStyles);
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: combinedStyles,
      children: token.content.replace(/ /g, '\u00A0')
    }, `${lineIndex}-${index}`);
  };

  // In the renderLine and renderToken flow
  const renderLine = (line, lineIndex) => {
    console.log(`Rendering line ${lineIndex}:`, line);
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: styles.lineContainer,
      children: line.map((token, tokenIndex) => renderToken(token, tokenIndex, lineIndex))
    }, lineIndex);
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    showsHorizontalScrollIndicator: _reactNative.Platform.OS !== 'web',
    style: styles.scrollView,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, index) => renderLine(line, index))
    })
  });
};
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map