"use strict";

import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { getRNStylesFromShikiStyle } from '../../utils/style-transformer';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const styles = StyleSheet.create({
  scrollView: {
    flex: 1,
    minHeight: 20
  },
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme
}) => {
  console.log('theme:', theme);
  const stylesheet = useMemo(() => {
    const styles = getRNStylesFromShikiStyle(theme);
    console.log('Generated stylesheet:', styles);
    return styles;
  }, [theme]);
  const {
    tokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId,
    theme
  });
  const renderToken = (token, index, lineIndex) => {
    // Ensure to collect all styles associated with the token's scopes
    const tokenScopes = Array.isArray(token.scope) ? token.scope : [token.scope];
    const tokenStylesArray = tokenScopes.map(scope => stylesheet[scope] || {});
    const combinedStyles = StyleSheet.flatten([...tokenStylesArray, {
      fontFamily: monospaceFont,
      ...(token.color && {
        color: token.color
      }),
      ...(token.fontStyle === 'italic' && stylesheet.italic),
      ...(token.fontWeight === 'bold' && stylesheet.bold)
    }]);
    console.log(`Rendering token: ${token.content}, styles:`, combinedStyles);
    return /*#__PURE__*/_jsx(Text, {
      style: combinedStyles,
      children: token.content.replace(/ /g, '\u00A0')
    }, `${lineIndex}-${index}`);
  };

  // In the renderLine and renderToken flow
  const renderLine = (line, lineIndex) => {
    console.log(`Rendering line ${lineIndex}:`, line);
    return /*#__PURE__*/_jsx(View, {
      style: styles.lineContainer,
      children: line.map((token, tokenIndex) => renderToken(token, tokenIndex, lineIndex))
    }, lineIndex);
  };
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    showsHorizontalScrollIndicator: Platform.OS !== 'web',
    style: styles.scrollView,
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, index) => renderLine(line, index))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map